##### Definition Variable Approach #####

# Load the data
nlsy_math_occ<-read.table("C:/GRE2016/Data/nlsy_math_wide_occ_A.dat", na.string='.')

# Give the variable names
names(nlsy_math_occ)<-c('id','female','lb_wght','anti_k1',
                        'math1','math2','math3','math4','age1','age2',
                        'age3','age4','grade1','grade2','grade3','grade4',
                        'men1','men2','men3','men4',
                        'spring1','spring2','spring3','spring4',
                        'anti1','anti2','anti3','anti4')
# Attach Data
attach(nlsy_math_occ)

nlsy_math_occ$age1_c8 <- age1/12 - 8
nlsy_math_occ$age2_c8 <- age2/12 - 8
nlsy_math_occ$age3_c8 <- age3/12 - 8
nlsy_math_occ$age4_c8 <- age4/12 - 8

library(OpenMx)

lg.math.age.omx <- mxModel("Linear Growth, Path Specification",
 type="RAM", mxData(observed=nlsy_math_occ,type="raw"),
 manifestVars=c("math1","math2","math3","math4"), latentVars=c("eta_1","eta_2"),

# residual variance paths 
mxPath(from=c("math1","math2","math3","math4"),
 arrows=2, free=TRUE, values=40, labels="th"),

# latent variable variances and covariance 
mxPath(from=c("eta_1","eta_2"), arrows=2, connect='unique.pairs',
 free=TRUE, values=c(1,0,1), labels=c("psi_11","psi_21","psi_22")),

# regression weights 
mxPath(from="eta_1", to=c("math1","math2","math3","math4"),
 arrows=1, free=FALSE, values=1),

mxPath(from="eta_2", to=c("math1","math2","math3","math4"),
 arrows=1, free=FALSE, labels=c("data.age1_c8","data.age2_c8","data.age3_c8","data.age4_c8")),

# means and intercepts
mxPath(from="one", to=c("eta_1","eta_2"),
 arrows=1, free=TRUE, values=c(40, 4), labels=c("alpha_1","alpha_2"))

) # close model

lg.math.age.fit <- mxRun(lg.math.age.omx)
summary(lg.math.age.fit)

#free parameters:
#     name matrix   row   col  Estimate  Std.Error lbound ubound
#1      th      S math1 math1 32.155103 1.68320829              
#2  psi_11      S eta_1 eta_1 64.831504 5.43664706              
#3  psi_21      S eta_1 eta_2  1.321083 0.97891480              
#4  psi_22      S eta_2 eta_2  0.675238 0.27406093              
#5 alpha_1      M     1 eta_1 35.173137 0.34659212              
#6 alpha_2      M     1 eta_2  4.256553 0.08095491              
#
#observed statistics:  2221 
#estimated parameters:  6 
#degrees of freedom:  2215 
#-2 log likelihood:  15843.14 
#saturated -2 log likelihood:  NA 
#number of observations:  932 
#chi-square:  NA 
#p:  NA 
#Information Criteria: 
#     df Penalty Parameters Penalty Sample-Size Adjusted
#AIC: 11413.1366           15855.14                   NA
#BIC:   698.4444           15884.16             15865.11
#CFI: NA 
#TLI: NA 
#RMSEA:  NA 


##### Time Window Approach #####

# Load the data
nlsy_math_age<-read.table("C:/GRE2016/Data/nlsy_math_wide_age.dat", na.string='.')

# Give the variable names
names(nlsy_math_age)<-c('id','female','lb_wght','anti_k1',
                        'math70','math75','math80','math85','math90','math95',
                        'math100','math105','math110','math115','math120','math125',
                        'math130','math135','math140','math145',
                        'grade70','grade75','grade80','grade85','grade90','grade95',
                        'grade100','grade105','grade110','grade115','grade120','grade125',
                        'grade130','grade135','grade140','grade145',
                        'men70','men75','men80','men85','men90','men95',
                        'men100','men105','men110','men115','men120','men125',
                        'men130','men135','men140','men145',
                        'spring70','spring75','spring80','spring85','spring90','spring95',
                        'spring100','spring105','spring110','spring115','spring120','spring125',
                        'spring130','spring135','spring140','spring145',
                        'anti70','anti75','anti80','anti85','anti90','anti95',
                        'anti100','anti105','anti110','anti115','anti120','anti125',
                        'anti130','anti135','anti140','anti145')
# Attach Data
attach(nlsy_math_age)

lg.math.age.omx <- mxModel("Linear Growth, Path Specification", type="RAM", 
 mxData(observed=nlsy_math_age, type="raw" ),
 manifestVars=c("math70","math75","math80","math85","math90","math95",                 
                "math100","math105","math110","math115","math120","math125",
                "math130","math135","math140","math145"),
 latentVars=c("eta_1","eta_2"),

# residual variance paths
mxPath(from=c("math70","math75","math80","math85","math90","math95",                                             
              "math100","math105","math110","math115","math120","math125", 
              "math130","math135","math140","math145"),
 arrows=2, free=TRUE, values=40, labels="th"),

# latent variable variances and covariances 
mxPath(from=c("eta_1","eta_2"), arrows=2, connect='unique.pairs',
 free=TRUE, values=c(1,0,1), labels=c("psi_11","psi_21","psi_22")),

# regression weights
mxPath(from="eta_1", 
 to=c("math70","math75","math80","math85","math90","math95",
      "math100","math105","math110","math115","math120","math125",
      "math130","math135","math140","math145"),
 arrows=1, free=FALSE, values=1),

mxPath(from="eta_2", 
 to=c("math70","math75","math80","math85","math90","math95",
      "math100","math105","math110","math115","math120","math125",
      "math130","math135","math140","math145"),
 arrows=1, free=FALSE, values=c(-1, -.5, 0, .5, 1, 1.5, 2, 2.5, 3, 3.5, 4, 4.5, 5, 5.5, 6, 6.5)),

# means and intercepts
mxPath(from="one", to=c("eta_1","eta_2"),
 arrows=1, free=TRUE, values=c(40, 4), labels=c("alpha_1","alpha_2"))

) # close model

lg.math.age.fit <- mxRun(lg.math.age.omx)
summary(lg.math.age.fit)

#free parameters:
#     name matrix    row    col   Estimate  Std.Error lbound ubound
#1      th      S math70 math70 32.2186746 1.69205224              
#2  psi_11      S  eta_1  eta_1 65.1221634 5.61061586              
#3  psi_21      S  eta_1  eta_2  1.1645448 1.03480061              
#4  psi_22      S  eta_2  eta_2  0.7283302 0.27732660              
#5 alpha_1      M      1  eta_1 35.0739983 0.34855852              
#6 alpha_2      M      1  eta_2  4.2290589 0.08134569              
#
#observed statistics:  2221 
#estimated parameters:  6 
#degrees of freedom:  2215 
#-2 log likelihood:  15855.89 
#saturated -2 log likelihood:  NA 
#number of observations:  932 
#chi-square:  NA 
#p:  NA 
#Information Criteria: 
#     df Penalty Parameters Penalty Sample-Size Adjusted
#AIC: 11425.8900           15867.89                   NA
#BIC:   711.1979           15896.91             15877.86
#CFI: NA 
#TLI: NA 
#RMSEA:  NA 
