###########################################################
## File Name: Chapter4_nlme_Grimm_Ram_Estabrook.R        ## 
## Read data, Plot Data,                                 ##
## fit age-based growth models                           ##
## By Kevin J. Grimm                                     ##
###########################################################

library(nlme)

# Load the data
nlsy_math_long<-read.table("C:/GRE2016/Data/nlsy_math_long_R.dat", na.strings='.')

# Give the variable names
names(nlsy_math_long)<-c('id', 'female', 'low_birth_weight', 'anti_k1', 'math', 'grade', 'occ', 'age', 'men', 'spring', 'anti')

attach(nlsy_math_long)

#Plot of the Longitudinal Data
#interaction.plot(grade,c_id,math,xlab='Grade',ylab='PIAT Mathematics',legend=F)

library(ggplot2)

age_years <- age/12

plot_obs <- ggplot(data=nlsy_math_long, aes(x = age_years, y = math, group = id)) + 
                geom_line() + 
                theme_bw() + 
                scale_x_continuous(breaks = 6:15, name = "Age") +  
                scale_y_continuous(name = "PIAT Mathematics")

print(plot_obs)

age_yr_c8 <- age/12 - 8

library(nlme)

#Using lme to fit Linear Growth Model to Mathematics Data with Age as Time-Metric

lg.math.age.lme <- lme(math ~ age_yr_c8, random= ~ age_yr_c8 |id, data = nlsy_math_long, method="ML")
summary(lg.math.age.lme)

#Linear mixed-effects model fit by maximum likelihood
# Data: nlsy_math_long 
#       AIC      BIC    logLik
#  15855.14 15889.37 -7921.568
#
#Random effects:
# Formula: ~age_yr_c8 | id
# Structure: General positive-definite, Log-Cholesky parametrization
#            StdDev    Corr  
#(Intercept) 8.0516603 (Intr)
#age_yr_c8   0.8216792 0.2   
#Residual    5.6705894       
#
#Fixed effects: math ~ age_yr_c8 
#               Value Std.Error   DF   t-value p-value
#(Intercept) 35.17313 0.3463332 1288 101.55867       0
#age_yr_c8    4.25656 0.0804632 1288  52.90068       0
# Correlation: 
#          (Intr)
#age_yr_c8 -0.453



#Using nlme to fit Linear Growth Model to Mathematics Data with Age as Time-Metric
lg.math.age.nlme <- nlme(math~(beta_1+d_1i)+(beta_2+d_2i)*(age/12-8),
                     data=nlsy_math_long,
                     fixed=beta_1+beta_2~1,
                     random=d_1i+d_2i~1|id,
                     start=c(beta_1=35, beta_2=4))

summary (lg.math.age.nlme)

#Nonlinear mixed-effects model fit by maximum likelihood
#  Model: math ~ (beta_1 + d_1i) + (beta_2 + d_2i) * (age/12 - 8) 
# Data: nlsy_math_long 
#       AIC      BIC    logLik
#  15855.14 15889.37 -7921.568
#
#Random effects:
# Formula: list(d_1i ~ 1, d_2i ~ 1)
# Level: id
# Structure: General positive-definite, Log-Cholesky parametrization
#         StdDev    Corr
#d_1i     8.0516834 d_1i
#d_2i     0.8216866 0.2 
#Residual 5.6705744     
#
#Fixed effects: beta_1 + beta_2 ~ 1 
#          Value Std.Error   DF   t-value p-value
#beta_1 35.17313 0.3463334 1288 101.55859       0
#beta_2  4.25656 0.0804631 1288  52.90071       0
# Correlation: 
#       beta_1
#beta_2 -0.453
#
#Standardized Within-Group Residuals:
#         Min           Q1          Med           Q3          Max 
#-3.382125777 -0.516299141  0.003860264  0.528128406  2.651445396 
#
#Number of Observations: 2221
#Number of Groups: 932 




#Using nlme to fit Linear Growth Model to Mathematics Data with Age as Time-Metric
lg.math.age.nlme <- nlme(math~b_1i+b_2i*(age/12-8),  
                   data=nlsy_math_long,                      
                   fixed=b_1i+b_2i~1,                      
                   random=b_1i+b_2i~1,
                   group=~id,                      
                   start=c(b_1i=35, b_2i=4),
                   na.action="na.omit")

summary (lg.math.age.nlme)

#Nonlinear mixed-effects model fit by maximum likelihood
#  Model: math ~ b_1i + b_2i * (age/12 - 8) 
# Data: nlsy_math_long 
#       AIC      BIC    logLik
#  15855.14 15889.37 -7921.568
#
#Random effects:
# Formula: list(b_1i ~ 1, b_2i ~ 1)
# Level: id
# Structure: General positive-definite, Log-Cholesky parametrization
#         StdDev    Corr
#b_1i     8.0516837 b_1i
#b_2i     0.8216858 0.2 
#Residual 5.6705748     
#
#Fixed effects: b_1i + b_2i ~ 1 
#        Value Std.Error   DF   t-value p-value
#b_1i 35.17313 0.3463334 1288 101.55858       0
#b_2i  4.25656 0.0804631 1288  52.90072       0
# Correlation: 
#     b_1i  
#b_2i -0.453
#
#Standardized Within-Group Residuals:
#         Min           Q1          Med           Q3          Max 
#-3.382126623 -0.516299335  0.003860157  0.528128502  2.651445509 
#
#Number of Observations: 2221
#Number of Groups: 932 




##LME4 
library(lme4)


lg.math.age.lmer <- lmer(math ~ 1 + age_yr_c8 + (1 + age_yr_c8 | id), data = nlsy_math_long, REML = FALSE)
summary(lg.math.age.lmer)

#Linear mixed model fit by maximum likelihood  ['lmerMod']
#Formula: math ~ 1 + age_yr_c8 + (1 + age_yr_c8 | id)
#   Data: nlsy_math_long
#
#     AIC      BIC   logLik deviance df.resid 
# 15855.1  15889.4  -7921.6  15843.1     2215 
#
#Scaled residuals: 
#    Min      1Q  Median      3Q     Max 
#-3.3821 -0.5163  0.0039  0.5281  2.6514 
#
#Random effects:
# Groups   Name        Variance Std.Dev. Corr
# id       (Intercept) 64.8298  8.0517       
#          age_yr_c8    0.6752  0.8217   0.20
# Residual             32.1553  5.6706       
#Number of obs: 2221, groups:  id, 932
#
#Fixed effects:
#            Estimate Std. Error t value
#(Intercept) 35.17313    0.34618  101.60
#age_yr_c8    4.25656    0.08043   52.92
#
#Correlation of Fixed Effects:
#          (Intr)
#age_yr_c8 -0.453


