ODS GRAPHICS OFF;
ODS HTML CLOSE;
ODS LISTING;

DATA nlsy_math_long;
	INFILE 'C:\GRE2016\Data\nlsy_math_long_R.dat';
	INPUT 
		id	    female 	    low_birth_weight	    anti_k1

		math 	grade		occ						age
		men		spring		anti;
RUN;

** Smaller Sample;
DATA ids;
	SET nlsy_math_long;
	BY id;
	IF first.id ne 1 THEN DELETE;
	ran_num = RANUNI(20111129);
	KEEP id ran_num;
RUN;
DATA nlsy_math_long1;
	MERGE ids nlsy_math_long;
	BY id;

	age_years = age/12;
RUN;

*Plotting Scores over time;
GOPTIONS
	FTEXT = ARIAL
	CTEXT = BLACK
	HTEXT = 1.5;
PROC GPLOT DATA = nlsy_math_long1;
	TITLE1 'PIAT Mathematics by Age';
	SYMBOL
		Interpol=join
		Color=black
		Repeat=50000
		Value=dot
		Height=.5
		Width=1;
	AXIS1
		LABEL = (F=ARIAL H = 2 A=90 'PIAT Mathematics')
		ORDER = (0 to 90 BY 10)
		MINOR = none;
	AXIS2
		LABEL = (F=ARIAL H = 2 'Age at Testing')
		ORDER = (6 to 15 BY 1)
		OFFSET= (5 PCT, 5 PCT)
		MINOR = none;

	PLOT math * age_years = id/NOLEGEND VAXIS= AXIS1 HAXIS=AXIS2;
RUN;

* Smaller Random Sample;

PROC GPLOT DATA = nlsy_math_long1 (WHERE = (ran_num < .05));
	TITLE1 'PIAT Mathematics by Age';
	SYMBOL
		Interpol=join
		Color=black
		Repeat=50000
		Value=dot
		Height=.5
		Width=1;
	AXIS1
		LABEL = (F=ARIAL H = 2 A=90 'PIAT Mathematics')
		ORDER = (0 to 90 BY 10)
		MINOR = none;
	AXIS2
		LABEL = (F=ARIAL H = 2 'Age')
		ORDER = (6 to 15 BY 1)
		OFFSET= (5 PCT, 5 PCT)
		MINOR = none;

	PLOT math * age_years = id/NOLEGEND VAXIS= AXIS1 HAXIS=AXIS2;
RUN;

*Linear Growth Model with Age at Testing (Years, centered at 8);
DATA nlsy_math_long2;
	SET nlsy_math_long1;
	age_yr_c8 = (age/12) - 8;
RUN;

PROC MIXED DATA = nlsy_math_long2 COVTEST;
	CLASS id;
	MODEL math = age_yr_c8/SOLUTION DDFM = BW;
	RANDOM INTERCEPT age_yr_c8 /SUBJECT = id TYPE = UNR;
RUN;

/*
                                   Covariance Parameter Estimates

                                                      Standard         Z
                 Cov Parm      Subject    Estimate       Error     Value        Pr Z

                 Var(1)        id          64.9679      5.5247     11.76      <.0001
                 Var(2)        id           0.6825      0.2807      2.43      0.0075
                 Corr(2,1)     id           0.1957      0.1869      1.05      0.2951
                 Residual                  32.1523      1.6993     18.92      <.0001


                                           Fit Statistics

                                -2 Res Log Likelihood         15846.9
                                AIC (smaller is better)       15854.9
                                AICC (smaller is better)      15854.9
                                BIC (smaller is better)       15874.2


                                   Null Model Likelihood Ratio Test

                                     DF    Chi-Square      Pr > ChiSq

                                      3        890.49          <.0001


                                      Solution for Fixed Effects

                                            Standard
                   Effect       Estimate       Error      DF    t Value    Pr > |t|

                   Intercept     35.1734      0.3464     931     101.53      <.0001
                   age_yr_c8      4.2567     0.08050    1288      52.88      <.0001
*/

*Linear Growth Model with Age at Testing (Years, centered at 8);
PROC NLMIXED DATA = nlsy_math_long; 
     b_1i = beta_1 + d_1i;
     b_2i = beta_2 + d_2i;
     traject = b_1i + b_2i*(age/12-8);
     MODEL math ~ NORMAL(traject, s_u*s_u); 
     RANDOM d_1i d_2i ~ NORMAL([0,0], [s_1*s_1,
                                       s_2*r_21*s_1,s_2*s_2]) SUBJECT = id; 
     PARMS beta_1 = 30 beta_2 = 5 s_1 = 10 r_21 = 0 s_2 = 2 s_u = 7;
RUN;
/*

                                            Fit Statistics

                               -2 Log Likelihood                  15843
                               AIC (smaller is better)            15855
                               AICC (smaller is better)           15855
                               BIC (smaller is better)            15884


                                         Parameter Estimates

                       Standard
Parameter   Estimate      Error     DF   t Value   Pr > |t|    Alpha      Lower      Upper   Gradient

beta_1       35.1731     0.3466    930    101.48     <.0001     0.05    34.4929    35.8533   -0.00012
beta_2        4.2566    0.08095    930     52.58     <.0001     0.05     4.0977     4.4154   -0.00037
s_1           8.0517     0.3426    930     23.50     <.0001     0.05     7.3793     8.7240   -0.00027
r_21          0.1997     0.1888    930      1.06     0.2903     0.05    -0.1707     0.5702   0.000437
s_2           0.8217     0.1706    930      4.82     <.0001     0.05     0.4869     1.1564   0.000141
s_u           5.6706     0.1499    930     37.83     <.0001     0.05     5.3764     5.9647   -0.00055
*/


***********************************************************************************
***********************************************************************************
			Organizing data according to measurement occasion & age
***********************************************************************************
***********************************************************************************;

DATA nlsy_math_long;
	INFILE 'C:\GRE2016\Data\nlsy_math_long_R.dat';
	INPUT 
		id	    female 	    low_birth_weight       anti_k1

		math 	grade		occ						age
		men		spring		anti;
RUN;

** By Occasion;
DATA nlsy_math_long1;
	SET nlsy_math_long;
	occ = occ - 1;
RUN;
PROC FREQ DATA = nlsy_math_long1;
	TABLES occ;
RUN;

PROC SORT DATA = nlsy_math_long1;
	BY id occ;
RUN;
DATA nlsy_math_wide1;
	ARRAY mth[4] 		mth1-mth4;
	ARRAY ag[4] 		ag1-ag4;
	ARRAY grd[4] 		grd1-grd4;
	ARRAY mn[4] 		mn1-mn4;
	ARRAY sprng[4] 		sprng1-sprng4;
	ARRAY ant[4] 		ant1-ant4;

	RETAIN mth1-mth4;
	RETAIN ag1-ag4;
	RETAIN grd1-grd4;
	RETAIN mn1-mn4;
	RETAIN sprng1-sprng4;
	RETAIN ant1-ant4;

	SET nlsy_math_long1;
	BY id ;
	IF FIRST.id THEN DO I = 1 TO 4;
		mth[I] 	= .;
		ag[I] 	= .;
		grd[I] 	= .;
		mn[I] 	= .;
		sprng[I] 	= .;
		ant[I] 	= .;
	END;
	mth[occ] = math;
	ag[occ] = age;
	grd[occ] = grade;
	mn[occ] = men;
	sprng[occ] = spring;
	ant[occ]	= anti;

	IF LAST.id THEN OUTPUT;
	KEEP 
		id female low_birth_weight anti_k1

		mth1-mth4 ag1-ag4 grd1-grd4 mn1-mn4 sprng1-sprng4 ant1-ant4;
RUN;

DATA _NULL_;
	SET nlsy_math_wide1;
	FILE 'D:\GRE2016\Data\nlsy_math_wide_occ.dat' LINESIZE=1000;
	PUT 
		id female low_birth_weight anti_k1

		mth1-mth4 ag1-ag4 grd1-grd4 mn1-mn4 sprng1-sprng4 ant1-ant4;
RUN;

DATA nlsy_math_wide1a;
	SET nlsy_math_wide1;
	IF ag1 = . THEN ag1 = 150;
	IF ag2 = . THEN ag2 = 150;
	IF ag3 = . THEN ag3 = 150;
	IF ag4 = . THEN ag4 = 150;
RUN;
DATA _NULL_;
	SET nlsy_math_wide1a;
	FILE 'D:\GRE2016\Data\nlsy_math_wide_occ_A.dat' LINESIZE=1000;
	PUT 
		id female low_birth_weight anti_k1

		mth1-mth4 ag1-ag4 grd1-grd4 mn1-mn4 sprng1-sprng4 ant1-ant4;
RUN;

** By Age;
DATA nlsy_math_long2;
	SET nlsy_math_long1;
	age_yr = age/12;
	age_yr_r = ROUND(age_yr, .5);
RUN;
PROC FREQ;
	TABLES age_yr_r;
RUN;

PROC SORT DATA = nlsy_math_long2;
	BY id age;
RUN;
DATA nlsy_math_wide2;
	ARRAY mth[16] 		mth1-mth16;
	ARRAY grd[16] 		grd1-grd16;
	ARRAY mn[16] 		mn1-mn16;
	ARRAY sprng[16] 	sprng1-sprng16;
	ARRAY ant[16] 		ant1-ant16;

	RETAIN mth1-mth16;
	RETAIN grd1-grd16;
	RETAIN mn1-mn16;
	RETAIN sprng1-sprng16;
	RETAIN ant1-ant16;

	SET nlsy_math_long2;
	BY id ;
	IF FIRST.id THEN DO I = 1 TO 16;
		mth[I] 	= .;
		grd[I] 	= .;
		mn[I] 	= .;
		sprng[I] 	= .;
		ant[I] 	= .;
	END;
	mth[age_yr_r*2-13] = math;
	grd[age_yr_r*2-13] = grade;
	mn[age_yr_r*2-13] = men;
	sprng[age_yr_r*2-13] = spring;
	ant[age_yr_r*2-13]	= anti;

	IF LAST.id THEN OUTPUT;
	KEEP 
		id female low_birth_weight anti_k1

		mth1-mth16 grd1-grd16 mn1-mn16 sprng1-sprng16 ant1-ant16;
RUN;

DATA _NULL_;
	SET nlsy_math_wide2;
	FILE 'D:\GRE2016\Data\nlsy_math_wide_age.dat' LINESIZE=1000;
	PUT 
		id female low_birth_weight anti_k1

		mth1-mth16 grd1-grd16 mn1-mn16 sprng1-sprng16 ant1-ant16;
RUN;

